@@ -23,7 +23,7 @@
 # OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 #
-# $Id: param.sh,v 1.18 2025/03/21 02:42:54 babolo Exp $
+# $Id: param.sh,v 1.19 2025/12/14 23:11:13 babolo Exp $
 
 dir="${1}"
 
@@ -299,7 +299,8 @@ fi
 if [ -n "${NEEDGCC}" ]; then
    path=`"${echo}" ${PATH} | "${sed}" -e 's|:| |g'`
    CCLEXOR=` for i in ${path};                        \
-             do "${find}" $i -name gcc\* || true;     \
+             do "${find}" $i -name 'gcc*'  || true;   \
+                "${find}" $i -name 'gcc\*'  || true;  \
              done                                     \
            | "${sed}" -Ene 's|^/.+/(gcc[0-9]*)$|\1|p' \
            | "${sort}" -u                             \
